# datamallet

Datamallet is a collection of helpful functions and modules for the datascience workflow. 
At the moment, it features the following:
1) Automated data visualization.<br>
2) Scikit-learn compatible transformers for data manipulation for tabular data 
(data which can be found in a table either pure tabular/timeseries).

<br>

# Future roadmap
<br>
In the future, modules concerned with other parts of Machine learning 
(e.g. Computer vision, NLP, recommendation engine etc) can be added.<br> 
The idea is for this library to be the de-facto tool for expediting data science tasks

<br>

# Tests<br>
from the main directory, you can run the tests by simply running the pytest command